cumulusci.tasks.github.tests package
====================================

Submodules
----------


.. automodule:: cumulusci.tasks.github.tests.test_merge
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.tests.test_pull_request
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.tests.test_release
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.tests.test_release_report
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.tests.test_tag
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.tests.test_util
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.github.tests.util_github_api
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.github.tests
   :members:
   :undoc-members:
   :show-inheritance:
